@@ -2,10 +2,11 @@ use strict;
 use warnings;
 package Dist::Zilla::Catalyst::Helper;
 BEGIN {
-	our $VERSION = 0.08;# VERSION
+	our $VERSION = 0.09;# VERSION
 }
 use Moose;
 use Dist::Zilla::File::InMemory;
+use Path::Class;
 
 extends 'Catalyst::Helper';
 
@@ -32,12 +33,17 @@ sub mk_file {
 	# {dist_repo} name which dzil already creates if we don't regex it out we
 	# end up with {dist_repo}/{dist_repo}/{files} instead of just
 	# {dist_repo}/{files}
-	my $name = "$file_obj";
-	$name =~ s{[\w-]+/}{};
+	my $cat_file = file( "$file_obj" );
+	my $cat_dir  = $cat_file->dir;
+	my @path     = $cat_dir->dir_list;
+	shift @path;
+
+	# ok so this isn't really just a name, but that's what we're using it for
+	my $name = file( @path, $cat_file->basename );
 
 	my $file
 		= Dist::Zilla::File::InMemory->new({
-			name    => $name,
+			name    => $name->stringify,
 			content => $output,
 		});
 
@@ -60,7 +66,7 @@ Dist::Zilla::Catalyst::Helper - a subclass of Catalyst::Helper
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 DESCRIPTION
 
